import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class ClearElementCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.ClearElement")

    def execute(self, selector):
        requestObj = [selector]

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "ClearElement was successful", "ClearElement failed")




import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class ActivateAppCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.ActivateApp")

    def execute(self, bundleId):
        if bundleId is None:
            requestObj = []
        else:
            requestObj = [bundleId]

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "ActivateApp was successful", "ActivateApp failed")




import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class LaunchAppCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.LaunchApp")

    def execute(self, appId, activityId):
        requestObj = []
        if appId is None:
            requestObj.append(None)
        else:
            requestObj.append(appId)

        if activityId is not None:
            requestObj.append(activityId)

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "LaunchApp was successful", "LaunchApp failed")




import sys
import json

from testwizard.commands_core import CommandBase
from .IsAppInstalledResult import IsAppInstalledResult


class IsAppInstalledCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.IsAppInstalled")

    def execute(self, bundleId):
        if bundleId is None:
            requestObj = []
        else:
            requestObj = [bundleId]

        result = self.executeCommand(requestObj)

        return IsAppInstalledResult(result, "IsAppInstalled was successful", "IsAppInstalled failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class TouchAction_MoveToElementCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(
            self, testObject, "Mobile.TouchAction_MoveToElement")

    def execute(self, selector):
        requestObj = [selector]

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "TouchAction_MoveToElement was successful", "TouchAction_MoveToElement failed")
